aboutsummaryrefslogtreecommitdiffstats
path: root/src/lib/ffmpeg/avcodec.pas
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/ffmpeg/avcodec.pas')
-rw-r--r--src/lib/ffmpeg/avcodec.pas4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/ffmpeg/avcodec.pas b/src/lib/ffmpeg/avcodec.pas
index 2c98f8fa..066910a3 100644
--- a/src/lib/ffmpeg/avcodec.pas
+++ b/src/lib/ffmpeg/avcodec.pas
@@ -4700,14 +4700,14 @@ const
* Warning: This code is platform dependent and assumes constants
* to be 32 bit.
* This version does the following steps:
* 1) shr 6: shifts the sign bit to bit position 2
* 2) and $00000002: sets all other bits to zero
* positive EINVAL gives 0, negative gives 2
* 3) not: inverts all bits. This gives -1 and -3
* 4) + 2: positive EINVAL gives 1, negative -1
*)
const
- AVERROR_SIGN = not((EINVAL shr 6) and $00000002) + 2;
+ AVERROR_SIGN = not((EINVAL shr 30) and $00000002) + 2;
(*
#if EINVAL > 0
@@ -4700,14 +4700,14 @@ const
* to be 32 bit.
* This version does the following steps:
- * 1) shr 6: shifts the sign bit to bit position 2
+ * 1) shr 30: shifts the sign bit to bit position 2
* 2) and $00000002: sets all other bits to zero
* positive EINVAL gives 0, negative gives 2